%global __cargo_skip_build 0
%global dracutmodulesdir %(pkg-config --variable=dracutmodulesdir dracut || echo '/usr/lib/dracut/modules.d')
%global crate afterburn

Summary:        A one-shot cloud provider agent
Name:           rust-%{crate}
Version:        5.6.0
Release:        2%{?dist}
License:        ASL 2.0
URL:            https://crates.io/crates/afterburn
Source0:        https://crates.io/api/v1/crates/%{crate}/%{version}/download#/%{crate}-%{version}.crate
Source1:        https://github.com/coreos/%{crate}/releases/download/v%{version}/%{crate}-%{version}-vendor.tar.gz

Patch3000:      add-loongarch-support.patch

ExclusiveArch:  %{rust_arches}
BuildRequires:  cargo rust-toolset glibc-devel openssl-devel systemd

%description
Afterburn is a one-shot agent for cloud-like platforms which
interacts with provider-specific metadata endpoints. It is
typically used in conjunction with Ignition.

%package     -n %{crate}
Summary:        %{summary}
License:        ASL 2.0 and MIT and BSD and 0BSD
%{?systemd_requires}

%description -n %{crate}
Afterburn is a one-shot agent for cloud-like platforms which
interacts with provider-specific metadata endpoints. It is
typically used in conjunction with Ignition.

%package     -n %{crate}-dracut
Summary:        Dracut modules for afterburn
BuildRequires:  pkgconfig(dracut)
Requires:       %{crate} = %{version}-%{release}
Requires:       dracut
Requires:       dracut-network

%description -n %{crate}-dracut
Dracut module that enables afterburn and corresponding services
to run in the initramfs on boot.

%prep
%setup -n %{crate}-%{version}
%cargo_prep -V 1

%ifarch loongarch64
%patch3000 -p1
%endif

sed -e 's,@DEFAULT_INSTANCE@,core,' < \
  systemd/afterburn-sshkeys@.service.in > \
  systemd/afterburn-sshkeys@.service

%build
%cargo_build

%install
%make_install INSTALL="install -p -c"
mkdir -p %{buildroot}%{dracutmodulesdir}
cp -a dracut/* %{buildroot}%{dracutmodulesdir}

%check
%cargo_test

%post        -n %{crate}
%systemd_post afterburn.service
%systemd_post afterburn-checkin.service
%systemd_post afterburn-firstboot-checkin.service
%systemd_post afterburn-sshkeys@.service

%preun       -n %{crate}
%systemd_preun afterburn.service
%systemd_preun afterburn-checkin.service
%systemd_preun afterburn-firstboot-checkin.service
%systemd_preun afterburn-sshkeys@.service

%postun      -n %{crate}
%systemd_postun afterburn.service
%systemd_postun afterburn-checkin.service
%systemd_postun afterburn-firstboot-checkin.service
%systemd_postun afterburn-sshkeys@.service

%files       -n %{crate}
%license LICENSE
%doc README.md
%{_bindir}/afterburn
%{_unitdir}/afterburn.service
%{_unitdir}/afterburn-checkin.service
%{_unitdir}/afterburn-firstboot-checkin.service
%{_unitdir}/afterburn-sshkeys@.service
%{_unitdir}/afterburn-sshkeys.target

%files       -n %{crate}-dracut
%{dracutmodulesdir}/30afterburn/

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.6.0-2
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Sat Aug 31 2024 Upgrade Robot <upbot@opencloudos.tech> - 5.6.0-1
- Upgrade to version 5.6.0

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.4.3-7
- Rebuilt for loongarch release

* Wed Jul 17 2024 Rebuild Robot <rebot@opencloudos.org> - 5.4.3-6
- [Type] bugfix
- [DESC] Rebuilt for rust-toolset

* Sat Jul 06 2024 Zhai Liangliang <zhailiangliang@loongson.cn> - 5.4.3-5
- [Type] other
- [DESC] Remove macro loongarch64 for avoiding not finding loongarch patch

* Thu Jun 13 2024 Zhai Liangliang <zhailiangliang@loongson.cn> - 5.4.3-4
- [Type] other
- [DESC] Fix build error for loongarch64

* Wed Nov 01 2023 cunshunxia <cunshunxia@tencent.com> - 5.4.3-3
- optimize the summary and description.

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.4.3-2
- Rebuilt for OpenCloudOS Stream 23.09

* Mon Jul 24 2023 Kui Ji <jackeyji@tencent.com> - 5.4.3-1
- upgrade to 5.4.3

* Tue Jul 18 2023 Wang Guodong <gordonwwang@tencent.com> - 5.3.0-5
- Rebuilt for rust 1.69.0

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.3.0-4
- Rebuilt for OpenCloudOS Stream 23.05

* Mon Apr 03 2023 Xiaojie Chen <jackxjchen@tencent.com> - 5.3.0-3
- Add buildrequires rust-toolset

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.3.0-2
- Rebuilt for OpenCloudOS Stream 23

* Mon Mar 06 2023 cunshunxia <cunshunxia@tencent.com> - 5.3.0-1
- initial build
